// SPDX-License-Identifier: GPL-3.0-only

use crate::reader::AheadReader;

use std::io::BufReader;
use std::{
    fs::File,
    io::{self, Write},
};

pub const BUFSIZE: usize = 64 * 1024; // 64 KiB

pub(crate) fn read_from_file_or_stdin<S: AsRef<str>>(
    input_file: Option<S>,
    bufsz: usize,
) -> AheadReader {
    match input_file {
        Some(f) => AheadReader::from(
            Box::new(BufReader::new(File::open(f.as_ref()).unwrap())),
            bufsz,
        ),
        None => AheadReader::from(Box::new(io::stdin().lock()), bufsz),
    }
}

pub(crate) fn write_to_file_or_stdout<S: AsRef<str>>(output_file: Option<S>) -> Box<dyn Write> {
    match output_file {
        Some(f) => Box::new(File::create(f.as_ref()).unwrap()),
        None => Box::new(io::stdout()),
    }
}
